@@ -14,7 +14,6 @@ from scipy.spatial import cKDTree
 
 from reVX.handlers.outputs import Outputs
 from reVX.plexos.utilities import DataCleaner, get_coord_labels
-from reVX.utilities.utilities import log_versions
 
 logger = logging.getLogger(__name__)
 
@@ -57,7 +56,6 @@ class PlexosNode:
             meta indices where n is the number of generation points. None if no
             forecast data being considered, by default None
         """
-        log_versions(logger)
         self._sc_build = \
             DataCleaner.rename_cols(sc_build,
                                     name_map=DataCleaner.REV_NAME_MAP)
@@ -125,8 +123,11 @@ class PlexosNode:
                                 'gid_count': gid_counts,
                                 'gid_capacity': gid_capacity})
         sc_meta = sc_meta.sort_values(by='gen_gid')
+        sc_meta = sc_meta[(sc_meta.gid_capacity > 0)]
 
         with Outputs(self._cf_fpath, mode='r') as cf_outs:
+            gen_gids = list(sc_meta['gen_gid'].values)
+            gen_gids = [a for b in gen_gids for a in b]
             cf_mean = cf_outs['cf_mean', list(sc_meta['gen_gid'].values)]
 
         sc_meta['cf_mean'] = cf_mean
@@ -274,6 +275,12 @@ class PlexosNode:
             logger.error(msg)
             raise RuntimeError(msg)
 
+        if profile is None:
+            msg = ('PlexosNode object could not build profile for '
+                   'sc buildout: {}'.format(self._sc_build))
+            logger.error(msg)
+            raise RuntimeError(msg)
+
         if len(profile.shape) != 1:
             profile = profile.flatten()
 
