@@ -14,9 +14,8 @@ from scipy.spatial import cKDTree
 from geopandas import GeoDataFrame
 from warnings import warn
 
-from rex.rechunk_h5 import to_records_array
 from rex.utilities.execution import SpawnProcessPool
-from rex.utilities.utilities import parse_table
+from rex.utilities.utilities import parse_table, to_records_array
 
 from reVX.utilities.region_classifier import RegionClassifier
 from reVX.handlers.outputs import Outputs
@@ -366,7 +365,7 @@ class PlexosAggregation(BaseProfileAggregation):
                 gid_col = list(gid_col)
 
             for i, sc_gids in enumerate(gid_col):
-                if any([m in sc_gids for m in missing]):
+                if any(m in sc_gids for m in missing):
                     bad_sc_points.append(self.sc_build.iloc[i]['sc_gid'])
 
             wmsg = ('There are {} SC points with missing gids: {}'
