@@ -19,6 +19,7 @@ logger = logging.getLogger(__name__)
 
 
 @click.group()
+@click.version_option(version=__version__)
 @click.option('--name', '-n', default='MeanWindDirs', type=STR,
               show_default=True,
               help='Job name.')
@@ -42,14 +43,6 @@ def valid_config_keys():
     click.echo(', '.join(get_class_properties(MeanWindDirsConfig)))
 
 
-@main.command()
-def version():
-    """
-    print version
-    """
-    click.echo(__version__)
-
-
 def run_local(ctx, config):
     """
     Run MeanWindDirections locally using config
@@ -199,12 +192,12 @@ def local(ctx, res_h5_fpath, excl_fpath, wdir_dsets, out_dir, tm_dset,
 
 def get_node_cmd(config):
     """
-    Get the node CLI call for prominent wind direction computation.
+    Get the node CLI call for mean wind direction computation.
 
     Parameters
     ----------
-    config : reVX.config.wind_dirs.WindDirsConfig
-        Wind Directions config object.
+    config : reVX.config.mean_wind_dirs.MeanWindDirsConfig
+        Mean Wind Directions config object.
 
     Returns
     -------
