@@ -19,6 +19,7 @@ logger = logging.getLogger(__name__)
 
 
 @click.group()
+@click.version_option(version=__version__)
 @click.option('--name', '-n', default='ProminentWindDirs', type=STR,
               show_default=True,
               help='Job name. Default is "ProminentWindDirs".')
@@ -42,14 +43,6 @@ def valid_config_keys():
     click.echo(', '.join(get_class_properties(ProminentWindDirsConfig)))
 
 
-@main.command()
-def version():
-    """
-    print version
-    """
-    click.echo(__version__)
-
-
 def run_local(ctx, config):
     """
     Run ProminentWindDirections locally using config
