@@ -7,15 +7,17 @@ from concurrent.futures import as_completed
 import fiona
 import geopandas as gpd
 import logging
+import numpy as np
 import os
 from rasterio import features
 import re
 from shapely.geometry import shape
 from warnings import warn
 
-from rex.utilities import parse_table, SpawnProcessPool
+from rex.utilities import parse_table, SpawnProcessPool, log_mem
 from reV.handlers.exclusions import ExclusionLayers
 from reVX.utilities.exclusions_converter import ExclusionsConverter
+from reVX.utilities.utilities import log_versions
 
 logger = logging.getLogger(__name__)
 
@@ -26,12 +28,12 @@ class BaseWindSetbacks(ABC):
     """
     MULTIPLIERS = {'high': 3, 'moderate': 1.1}
 
-    def __init__(self, excl_h5, hub_height, rotor_diameter, regs_fpath=None,
+    def __init__(self, excl_fpath, hub_height, rotor_diameter, regs_fpath=None,
                  multiplier=None, hsds=False, chunks=(128, 128)):
         """
         Parameters
         ----------
-        excl_h5 : str
+        excl_fpath : str
             Path to .h5 file containing exclusion layers, will also be the
             location of any new setback layers
         hub_height : float | int
@@ -53,19 +55,20 @@ class BaseWindSetbacks(ABC):
             behind HSDS, by default False
         chunks : tuple, optional
             Chunk size to use for setback layers, if None use default chunk
-            size in excl_h5, by default (128, 128)
+            size in excl_fpath, by default (128, 128)
         """
-        self._excl_h5 = excl_h5
+        log_versions(logger)
+        self._excl_fpath = excl_fpath
         self._hub_height = hub_height
         self._rotor_diameter = rotor_diameter
         self._hsds = hsds
         self._shape, self._chunks, self._profile = \
-            self._parse_excl_properties(excl_h5, chunks, hsds=hsds)
+            self._parse_excl_properties(excl_fpath, chunks, hsds=hsds)
 
         self._regs, self._multi = self._preflight_check(regs_fpath, multiplier)
 
     def __repr__(self):
-        msg = "{} for {}".format(self.__class__.__name__, self._excl_h5)
+        msg = "{} for {}".format(self.__class__.__name__, self._excl_fpath)
         return msg
 
     @property
@@ -174,13 +177,13 @@ class BaseWindSetbacks(ABC):
         return self.profile['crs']
 
     @staticmethod
-    def _parse_excl_properties(excl_h5, chunks, hsds=False):
+    def _parse_excl_properties(excl_fpath, chunks, hsds=False):
         """
-        Parse exclusions shape, chunk size, and profile from excl_h5 file
+        Parse exclusions shape, chunk size, and profile from excl_fpath file
 
         Parameters
         ----------
-        excl_h5 : str
+        excl_fpath : str
             Path to .h5 file containing exclusion layers, will also be the
             location of any new setback layers
         chunks : tuple | None
@@ -198,7 +201,7 @@ class BaseWindSetbacks(ABC):
         profile : str
             GeoTiff profile for exclusions datasets
         """
-        with ExclusionLayers(excl_h5, hsds=hsds) as exc:
+        with ExclusionLayers(excl_fpath, hsds=hsds) as exc:
             shape = exc.shape
             profile = exc.profile
             if chunks is None:
@@ -309,6 +312,7 @@ class BaseWindSetbacks(ABC):
         """
         logger.debug('- Computing setbacks for county FIPS {}'
                      .format(cnty.iloc[0]['FIPS']))
+        log_mem(logger)
         mask = features.centroid.within(cnty['geometry'].values[0])
         tmp = features.loc[mask]
         tmp.loc[:, 'geometry'] = tmp.buffer(setback)
@@ -348,7 +352,7 @@ class BaseWindSetbacks(ABC):
 
         logger.info('Merging county geometries w/ local wind '
                     'regulations')
-        with ExclusionLayers(self._excl_h5) as exc:
+        with ExclusionLayers(self._excl_fpath) as exc:
             fips = exc['cnty_fips']
             profile = exc.get_layer_profile('cnty_fips')
 
@@ -379,6 +383,7 @@ class BaseWindSetbacks(ABC):
         try:
             regs = parse_table(regs_fpath)
             regs = self._parse_county_regs(regs)
+            log_mem(logger)
 
             out_path = regs_fpath.split('.')[0] + '.gpkg'
             logger.debug('Saving wind regulations with county geometries as: '
@@ -487,11 +492,13 @@ class BaseWindSetbacks(ABC):
         """
         logger.debug('Generating setbacks exclusion array of shape {}'
                      .format(self.arr_shape))
-        arr = features.rasterize(shapes=shapes,
-                                 out_shape=self.arr_shape[1:],
-                                 fill=0,
-                                 transform=self.profile['transform'],
-                                 dtype='uint8')
+        log_mem(logger)
+        arr = np.zeros(self.arr_shape[1:], dtype='uint8')
+        features.rasterize(shapes=shapes,
+                           out=arr,
+                           out_shape=self.arr_shape[1:],
+                           fill=0,
+                           transform=self.profile['transform'])
 
         return arr
 
@@ -547,6 +554,7 @@ class BaseWindSetbacks(ABC):
         if max_workers is None:
             max_workers = os.cpu_count()
 
+        log_mem(logger)
         if max_workers > 1:
             logger.info('Computing local setbacks in parallel using {} '
                         'workers'.format(max_workers))
@@ -555,12 +563,12 @@ class BaseWindSetbacks(ABC):
                                   loggers=loggers) as exe:
                 futures = []
                 for i in range(len(wind_regs)):
-                    cnty = wind_regs.iloc[[i]]
+                    cnty = wind_regs.iloc[[i]].copy()
                     setback = self._get_setback(cnty.iloc[0], self.hub_height,
                                                 self.rotor_diameter)
                     if setback is not None:
                         idx = features.sindex.intersection(cnty.total_bounds)
-                        cnty_feats = features.iloc[list(idx)]
+                        cnty_feats = features.iloc[list(idx)].copy()
                         future = exe.submit(self._compute_local_setbacks,
                                             cnty_feats, cnty, setback)
                         futures.append(future)
@@ -754,7 +762,7 @@ class StructureWindSetbacks(BaseWindSetbacks):
         return wind_regs
 
     @classmethod
-    def run(cls, excl_h5, structures_path, out_dir, hub_height,
+    def run(cls, excl_fpath, structures_path, out_dir, hub_height,
             rotor_diameter, regs_fpath=None, multiplier=None,
             chunks=(128, 128), max_workers=None, replace=False, hsds=False):
         """
@@ -765,7 +773,7 @@ class StructureWindSetbacks(BaseWindSetbacks):
 
         Parameters
         ----------
-        excl_h5 : str
+        excl_fpath : str
             Path to .h5 file containing exclusion layers, will also be the
             location of any new setback layers
         structure_path : str
@@ -789,7 +797,7 @@ class StructureWindSetbacks(BaseWindSetbacks):
             max-tip height, by default None
         chunks : tuple, optional
             Chunk size to use for setback layers, if None use default chunk
-            size in excl_h5, by default (128, 128)
+            size in excl_fpath, by default (128, 128)
         max_workers : int, optional
             Number of workers to use for setback computation, if 1 run in
             serial, if > 1 run in parallel with that many workers, if None
@@ -800,14 +808,14 @@ class StructureWindSetbacks(BaseWindSetbacks):
             Boolean flag to use h5pyd to handle .h5 'files' hosted on AWS
             behind HSDS, by default False
         """
-        setbacks = cls(excl_h5, hub_height, rotor_diameter,
+        setbacks = cls(excl_fpath, hub_height, rotor_diameter,
                        regs_fpath=regs_fpath, multiplier=multiplier,
                        hsds=hsds, chunks=chunks)
 
         structures_path = setbacks._get_feature_paths(structures_path)
 
         for fpath in structures_path:
-            geotiff = os.path.basename(fpath).replace('.geojson', '.geotiff')
+            geotiff = os.path.basename(fpath).replace('.geojson', '.tif')
             geotiff = os.path.join(out_dir, geotiff)
             if os.path.exists(geotiff) and not replace:
                 msg = ('{} already exists, setbacks will not be re-computed '
@@ -926,7 +934,7 @@ class RoadWindSetbacks(BaseWindSetbacks):
         return wind_regs
 
     @classmethod
-    def run(cls, excl_h5, roads_path, out_dir, hub_height,
+    def run(cls, excl_fpath, roads_path, out_dir, hub_height,
             rotor_diameter, regs_fpath=None, multiplier=None,
             chunks=(128, 128), max_workers=None, replace=False, hsds=False):
         """
@@ -937,7 +945,7 @@ class RoadWindSetbacks(BaseWindSetbacks):
 
         Parameters
         ----------
-        excl_h5 : str
+        excl_fpath : str
             Path to .h5 file containing exclusion layers, will also be the
             location of any new setback layers
         road_path : str
@@ -961,7 +969,7 @@ class RoadWindSetbacks(BaseWindSetbacks):
             max-tip height, by default None
         chunks : tuple, optional
             Chunk size to use for setback layers, if None use default chunk
-            size in excl_h5, by default (128, 128)
+            size in excl_fpath, by default (128, 128)
         max_workers : int, optional
             Number of workers to use for setback computation, if 1 run in
             serial, if > 1 run in parallel with that many workers, if None
@@ -972,13 +980,13 @@ class RoadWindSetbacks(BaseWindSetbacks):
             Boolean flag to use h5pyd to handle .h5 'files' hosted on AWS
             behind HSDS, by default False
         """
-        setbacks = cls(excl_h5, hub_height, rotor_diameter,
+        setbacks = cls(excl_fpath, hub_height, rotor_diameter,
                        regs_fpath=regs_fpath, multiplier=multiplier,
                        hsds=hsds, chunks=chunks)
 
         roads_path = setbacks._get_feature_paths(roads_path)
         for fpath in roads_path:
-            geotiff = os.path.basename(fpath).replace('.gdb', '.geotiff')
+            geotiff = os.path.basename(fpath).replace('.gdb', '.tif')
             geotiff = os.path.join(out_dir, geotiff)
             if os.path.exists(geotiff) and not replace:
                 msg = ('{} already exists, setbacks will not be re-computed '
@@ -1016,6 +1024,9 @@ class TransmissionWindSetbacks(BaseWindSetbacks):
         setbacks : list
             List of setback geometries
         """
+        logger.debug('- Computing setbacks for county FIPS {}'
+                     .format(cnty.iloc[0]['FIPS']))
+        log_mem(logger)
         tmp = gpd.clip(features, cnty)
         tmp = tmp[~tmp.is_empty]
 
@@ -1070,7 +1081,7 @@ class TransmissionWindSetbacks(BaseWindSetbacks):
         return regs
 
     @classmethod
-    def run(cls, excl_h5, features_fpath, out_dir, hub_height,
+    def run(cls, excl_fpath, features_fpath, out_dir, hub_height,
             rotor_diameter, regs_fpath=None, multiplier=None,
             chunks=(128, 128), max_workers=None, replace=False, hsds=False):
         """
@@ -1080,7 +1091,7 @@ class TransmissionWindSetbacks(BaseWindSetbacks):
         tip-height.
         Parameters
         ----------
-        excl_h5 : str
+        excl_fpath : str
             Path to .h5 file containing exclusion layers, will also be the
             location of any new setback layers
         features_fpath : str
@@ -1104,7 +1115,7 @@ class TransmissionWindSetbacks(BaseWindSetbacks):
             max-tip height, by default None
         chunks : tuple, optional
             Chunk size to use for setback layers, if None use default chunk
-            size in excl_h5, by default (128, 128)
+            size in excl_fpath, by default (128, 128)
         max_workers : int, optional
             Number of workers to use for setback computation, if 1 run in
             serial, if > 1 run in parallel with that many workers, if None
@@ -1116,14 +1127,14 @@ class TransmissionWindSetbacks(BaseWindSetbacks):
             behind HSDS, by default False
         """
         geotiff = os.path.basename(features_fpath).split('.')[0]
-        geotiff += '.geotiff'
+        geotiff += '.tif'
         geotiff = os.path.join(out_dir, geotiff)
         if os.path.exists(geotiff) and not replace:
             msg = ('{} already exists, setbacks will not be re-computed '
                    'unless replace=True'.format(geotiff))
             logger.error(msg)
         else:
-            setbacks = cls(excl_h5, hub_height, rotor_diameter,
+            setbacks = cls(excl_fpath, hub_height, rotor_diameter,
                            regs_fpath=regs_fpath, multiplier=multiplier,
                            hsds=hsds, chunks=chunks)
 
